@@ -191,7 +191,7 @@ class FileHeader(Block):
           of space from the oldest records and an event message could
           not be written to the log file.
         """
-        return self.flags() & 0x2
+        return self.flags() & 0x2 == 0x2
 
     def first_chunk(self):
         """
@@ -411,8 +411,11 @@ class ChunkHeader(Block):
         return Record(self._buf, self._offset + 0x200, self)
 
     def records(self):
-        record = self.first_record()
-        while record._offset < self._offset + self.next_record_offset():
+        try:
+            record = self.first_record()
+        except InvalidRecordException:
+            return
+        while record._offset < self._offset + self.next_record_offset() and record.length() > 0:
             yield record
             try:
                 record = Record(self._buf,
